@@ -1,4 +1,4 @@
-/* $Id: fsusage.h,v 1.18 2004/03/09 23:28:46 hadess Exp $ */
+/* $Id: fsusage.h,v 1.22 2004/07/17 12:09:01 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
 
@@ -33,9 +33,10 @@ G_BEGIN_DECLS
 #define GLIBTOP_FSUSAGE_BAVAIL		2
 #define GLIBTOP_FSUSAGE_FILES		3
 #define GLIBTOP_FSUSAGE_FFREE		4
-#define GLIBTOP_FSUSAGE_BLOCK_SIZE	6
-
-#define GLIBTOP_MAX_FSUSAGE		5
+#define GLIBTOP_FSUSAGE_BLOCK_SIZE	5
+#define GLIBTOP_FSUSAGE_READ           6
+#define GLIBTOP_FSUSAGE_WRITE          7
+#define GLIBTOP_MAX_FSUSAGE		8
 
 
 typedef struct _glibtop_fsusage		glibtop_fsusage;
@@ -48,7 +49,8 @@ struct _glibtop_fsusage
 		bavail,		/* Free blocks available to non-superuser. */
 		files,		/* Total file nodes. */
 		ffree;		/* Free file nodes. */
-	int	block_size;	/* Size of a block in bytes. */
+	guint32	block_size;	/* Size of a block in bytes. */
+	guint64 read, write;    /* Total blocks read and written */
 };
 
 #define glibtop_get_fsusage(fsusage,disk)	glibtop_get_fsusage_l(glibtop_global_server, fsusage, disk)
