@@ -1,4 +1,4 @@
-/* $Id: signal.h,v 1.7 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: signal.h,v 1.8 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,7 +30,7 @@
 #include <sys/signal.h>
 #endif
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef struct _glibtop_signame	glibtop_signame;
 
@@ -42,6 +42,6 @@ struct _glibtop_signame
 
 extern const glibtop_signame glibtop_sys_siglist [];
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
