@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.37 2005/12/12 09:38:08 jamesh Exp $ */
+/* $Id: init.c,v 1.33 2004/10/10 17:21:57 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,13 +21,9 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
-#include <glibtop/error.h>
 #include <glibtop/sysdeps.h>
-#include <glibtop/open.h>
 #include <glibtop/parameter.h>
-#include <glibtop/init_hooks.h>
 
 #ifndef DEFAULT_PORT
 #define DEFAULT_PORT 42800
@@ -221,7 +217,7 @@ glibtop *
 glibtop_init_s (glibtop **server_ptr, unsigned long features, unsigned flags)
 {
 	glibtop *server;
-	const glibtop_init_func_t *init_fkt;
+	glibtop_init_func_t *init_fkt;
 
 	if (server_ptr == NULL)
 		return NULL;
