@@ -1,22 +1,22 @@
 /* -*-C-*-
  * Server code for handling requests from clients and forwarding them
  * on to the GNU Emacs process.
- * 
+ *
  * This file is part of GNU Emacs.
- * 
+ *
  * Copying is permitted under those conditions described by the GNU
  * General Public License.
- * 
+ *
  * Copyright (C) 1989 Free Software Foundation, Inc.
- * 
+ *
  * Author: Andy Norman (ange@hplb.hpl.hp.com), based on 'etc/server.c'
  * from the 18.52 GNU Emacs distribution.
- * 
+ *
  * Please mail bugs and suggestions to the author at the above address.
  */
 
-/* HISTORY 
- * 11-Nov-1990                bristor@simba   
+/* HISTORY
+ * 11-Nov-1990                bristor@simba
  *    Added EOT stuff.
  */
 
@@ -29,11 +29,14 @@
  * ../etc/gnuserv.README relative to the directory containing this file)
  */
 
+#include <config.h>
+
+#include "libgtop-i18n.h"
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
 #include <glibtop/command.h>
-#include <glibtop/xmalloc.h>
+
 
 #include <glibtop/parameter.h>
 
@@ -42,7 +45,7 @@
 #include <glibtop/gnuserv.h>
 
 #include <errno.h>
-#include <popt-gnome.h>
+#include <popt.h>
 
 #include "daemon.h"
 
@@ -189,17 +192,22 @@ permitted (u_long host_addr, int fd)
 			auth_protocol);
 	return FALSE;
     }
-	
+
     if (!strcmp (auth_protocol, MCOOKIE_NAME)) {
-	/* 
+	/*
 	 * doing magic cookie auth
 	 */
-			
+
 	if (timed_read (fd, buf, 10, AUTH_TIMEOUT, 1) <= 0)
 	    return FALSE;
 
 	auth_data_len = atoi (buf);
 
+	if (auth_data_len < 1 || (size_t)auth_data_len > sizeof(buf)) {
+	    syslog_message(LOG_WARNING, "Invalid data length supplied by client");
+	    return FALSE;
+	}
+
 	if (timed_read (fd, buf, auth_data_len, AUTH_TIMEOUT, 0) != auth_data_len)
 	    return FALSE;
 
@@ -214,7 +222,7 @@ permitted (u_long host_addr, int fd)
 			"not compiled with Xauth");
 #endif
 
-	/* 
+	/*
 	 * auth failed, but allow this to fall through to the
 	 * GNU_SECURE protocol....
 	 */
@@ -230,12 +238,12 @@ permitted (u_long host_addr, int fd)
 				"trying GNU_SECURE auth...");
 	}
     }
-    
+
     /* Other auth protocols go here, and should execute only if
      * the * auth_protocol name matches. */
 
     /* Now, try the old GNU_SECURE stuff... */
-	
+
     if (enable_debug)
 	syslog_message (LOG_DEBUG, "Doing GNU_SECURE auth ...");
 
@@ -249,7 +257,7 @@ permitted (u_long host_addr, int fd)
 	if (host_addr == permitted_hosts [i])
 	    return (TRUE);
     }
-	
+
     return (FALSE);
 }
 
@@ -266,7 +274,12 @@ permitted (u_long host_addr, int fd)
 static int
 setup_table (void)
 {
-    char hostname [HOSTNAMSZ], screen [BUFSIZ];
+    char hostname [HOSTNAMSZ];
+
+#ifdef AUTH_MAGIC_COOKIE
+    char screen [BUFSIZ];
+#endif
+
     long host_addr;
     int i, hosts = 0;
 
@@ -354,7 +367,7 @@ internet_init (void)
 	syslog_io_message (LOG_ERR, "unable to create socket");
 	exit (1);
     }
-	
+
     /* Bind the listen address to the socket. */
     if (bind (ls, (struct sockaddr *) &server,
 	      sizeof (struct sockaddr_in)) == -1) {
@@ -425,7 +438,7 @@ handle_internet_request (int ls)
 
     close (s);
 
-    if (verbose_output)	
+    if (verbose_output)
 	syslog_message (LOG_INFO, "Closed connection to %s port %u.",
 			inet_ntoa (peer.sin_addr), ntohs (peer.sin_port));
 
@@ -452,11 +465,11 @@ const struct poptOption popt_options [] = {
       N_("Don't fork into background"), N_("NO-DAEMON") },
     { "inetd", 'i', POPT_ARG_NONE, &invoked_from_inetd, 0,
       N_("Invoked from inetd"), N_("INETD") },
-    { NULL, '\0', 0, NULL, 0 }
+    { NULL, '\0', 0, NULL, 0, NULL, NULL }
 };
 
 int
-main (int argc, char *argv [])
+main (int argc, const char **argv)
 {
     const unsigned method = GLIBTOP_METHOD_PIPE;
     const unsigned long features = GLIBTOP_SYSDEPS_ALL;
@@ -469,8 +482,8 @@ main (int argc, char *argv [])
     /* On non-glibc systems, this is not set up for us.  */
     if (!program_invocation_name) {
 	char *arg;
-	  
-	program_invocation_name = argv[0];
+
+	program_invocation_name = (char *) argv[0];
 	arg = strrchr (argv[0], '/');
 	program_invocation_short_name =
 	    arg ? (arg + 1) : program_invocation_name;
@@ -525,7 +538,7 @@ main (int argc, char *argv [])
      * SERVER_GID. Otherwise we completely drop any priviledges.
      */
 
-    if (enable_debug)		
+    if (enable_debug)
 	syslog_message (LOG_DEBUG, "Parent ID: (%d, %d) - (%d, %d)",
 			getuid (), geteuid (), getgid (), getegid ());
 
@@ -610,7 +623,7 @@ main (int argc, char *argv [])
 	    if (verbose_output)
 		syslog_message (LOG_INFO, "Child %d exited.", ret);
 	}
-		
+
 	FD_ZERO (&rmask);
 
 	/* Only the child accepts connections from standard
