@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.32 2003/10/20 13:55:30 hadess Exp $ */
+/* $Id: main.c,v 1.34 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -41,7 +41,7 @@ handle_parent_connection (int s)
     glibtop_mountentry *mount_list;
     char parameter [BUFSIZ];
     unsigned short device;
-    int64_t *param_ptr;
+    gint64 *param_ptr;
     int all_fs;
     pid_t pid;
     void *ptr;
@@ -64,18 +64,18 @@ handle_parent_connection (int s)
 	    syslog_message (LOG_DEBUG,
 			    "Parent (%d) received command %d from client.",
 			    getpid (), (int) cmnd->command);
-	
+
 	if (cmnd->data_size >= BUFSIZ) {
 	    syslog_message (LOG_WARNING,
 			    "Client sent %d bytes, but buffer is %d",
 			    cmnd->data_size, BUFSIZ);
 	    return;
 	}
-		
+
 	memset (resp, 0, sizeof (glibtop_response));
 
 	memset (parameter, 0, sizeof (parameter));
-		
+
 	if (cmnd->data_size) {
 	    if (enable_debug)
 		syslog_message (LOG_DEBUG, "Client has %d bytes of data.",
@@ -92,7 +92,7 @@ handle_parent_connection (int s)
 	    do_output (s, resp, 0, 0, NULL);
 	    return;
 	case GLIBTOP_CMND_SYSDEPS:
-	    memcpy (&resp->u.sysdeps, &server->sysdeps, 
+	    memcpy (&resp->u.sysdeps, &server->sysdeps,
 		    sizeof (glibtop_sysdeps));
 	    resp->u.sysdeps.features = GLIBTOP_SYSDEPS_ALL;
 	    do_output (s, resp, _offset_union (sysdeps), 0, NULL);
@@ -133,7 +133,7 @@ handle_parent_connection (int s)
 	    do_output (s, resp, _offset_data (sem_limits), 0, NULL);
 	    break;
 	case GLIBTOP_CMND_PROCLIST:
-	    param_ptr = (int64_t *) parameter;
+	    param_ptr = (gint64 *) parameter;
 	    ptr = glibtop_get_proclist_l (server,
 					  &resp->u.data.proclist,
 					  param_ptr [0],
