@@ -1,4 +1,4 @@
-/* $Id: sem_limits.c,v 1.16 2003/10/19 16:55:36 carlos Exp $ */
+/* $Id: sem_limits.c,v 1.18 2004/06/09 18:52:21 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -41,7 +41,7 @@ union semun
 };
 #endif
 
-static unsigned long _glibtop_sysdeps_sem_limits =
+static const unsigned long _glibtop_sysdeps_sem_limits =
 (1 << GLIBTOP_IPC_SEMMAP) + (1 << GLIBTOP_IPC_SEMMNI) +
 (1 << GLIBTOP_IPC_SEMMNS) + (1 << GLIBTOP_IPC_SEMMNU) +
 (1 << GLIBTOP_IPC_SEMMSL) + (1 << GLIBTOP_IPC_SEMOPM) +
@@ -62,17 +62,17 @@ void
 glibtop_get_sem_limits_s (glibtop *server, glibtop_sem_limits *buf)
 {
 	struct seminfo	seminfo;
-	union semun	arg;  
-  
+	union semun	arg;
+
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SEM_LIMITS, 0);
 
 	memset (buf, 0, sizeof (glibtop_sem_limits));
-  
+
 	buf->flags = _glibtop_sysdeps_sem_limits;
-  
+
 	arg.array = (ushort *) &seminfo;
 	semctl (0, 0, IPC_INFO, arg);
-  
+
 	buf->semmap = seminfo.semmap;
 	buf->semmni = seminfo.semmni;
 	buf->semmns = seminfo.semmns;
