@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.26 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: proctime.c,v 1.30 2004/10/26 20:26:25 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,9 +24,11 @@
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proctime.h>
+#include <glibtop/uptime.h>
 
 static const unsigned long _glibtop_sysdeps_proc_time =
 (1L << GLIBTOP_PROC_TIME_UTIME) + (1L << GLIBTOP_PROC_TIME_CUTIME) +
+(1L << GLIBTOP_PROC_TIME_RTIME) +
 (1L << GLIBTOP_PROC_TIME_STIME) + (1L << GLIBTOP_PROC_TIME_CSTIME) +
 (1L << GLIBTOP_PROC_TIME_FREQUENCY) + (1L << GLIBTOP_PROC_TIME_TIMEOUT) +
 (1L << GLIBTOP_PROC_TIME_IT_REAL_VALUE) + (1L << GLIBTOP_PROC_TIME_START_TIME);
@@ -65,16 +67,51 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 
 	p = skip_multiple_token (p, 11);
 
+	/* clock_t  (1/100 s) */
 	buf->utime  = strtoull (p, &p, 0);
 	buf->stime  = strtoull (p, &p, 0);
+	buf->rtime = buf->utime + buf->stime;
+
 	buf->cutime = strtoull (p, &p, 0);
 	buf->cstime = strtoull (p, &p, 0);
 
-	p = skip_multiple_token (p, 2);
+	p = skip_multiple_token (p, 3);
 
-	buf->timeout       = strtoull (p, &p, 0);
+	/* timeout is 0 on 2.4 and "thread_number" on 2.6
+	   lets skip it (using previous skip_multiple_token)
+	   buf->timeout       = strtoull (p, &p, 0);
+	*/
 	buf->it_real_value = strtoull (p, &p, 0);
-	buf->start_time    = strtoull (p, &p, 0);
+
+	/* seconds since epoch */
+	{
+	  /* Linux provides start_time as clock_t representing
+	     the start of <pid> after boot_time.
+	     Let's use glibtop_get_uptime to get boot_time.
+	     But i'm not sure if this is safe
+
+	     See libgtop documentation.
+
+	     #ifdef __KERNEL__
+	     ...
+	     *
+	     * Have the 32 bit jiffies value wrap 5 minutes after boot
+	     * so jiffies wrap bugs show up earlier.
+	     *
+	     #define INITIAL_JIFFIES ((unsigned long)(unsigned int) (-300*HZ))
+	     ...
+	     #endif
+
+	     start_time may be incremented by INITIAL_JIFFIES, so start_time
+	     may be not be exact. You may also get wrong start_time if your
+	     system clock is not synchronised with you hardware clock.
+	     'man hwclock'
+	  */
+	  glibtop_uptime up;
+	  glibtop_get_uptime_s(server, &up);
+
+	  buf->start_time = up.boot_time + strtoull (p, &p, 0) / 100;
+	}
 
 	buf->frequency = 100;
 
@@ -83,12 +120,11 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 	if (!server->ncpu)
 		return;
 
+	/* FIXME: doesn't work with 2.6 */
 	if (proc_file_to_buffer (buffer, "/proc/%d/cpu", pid))
 		return;
 
-	p = skip_token (buffer);
-	buf->utime  = strtoull (p, &p, 0);
-	buf->stime  = strtoull (p, &p, 0);
+	p = skip_multiple_token (p, 3);
 
 	for (i = 0; i < GLIBTOP_NCPU; i++) {
 		if (strncmp (p+1, "cpu", 3) || !isdigit (p [4]))
