@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.25 2005/07/23 00:01:11 bdejean Exp $ */
+/* $Id: uptime.c,v 1.21 2004/07/03 13:28:59 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,15 +24,10 @@
 #include <config.h>
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
-
-#include "glibtop_private.h"
-
 #include <time.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-  (1UL << GLIBTOP_UPTIME_UPTIME) \
-+ (1UL << GLIBTOP_UPTIME_IDLETIME) \
-+ (1UL << GLIBTOP_UPTIME_BOOT_TIME);
+(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
 
 /* Init function. */
 
@@ -57,9 +52,9 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 
 	file_to_buffer(server, buffer, FILENAME);
 
-	buf->uptime   = g_ascii_strtod (buffer, &p);
-	buf->idletime = g_ascii_strtod (p, &p);
-	buf->boot_time = get_boot_time(server);
+	buf->uptime   = strtod (buffer, &p);
+	buf->idletime = strtod (p, &p);
+	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
