@@ -1,4 +1,4 @@
-/* $Id: cpu.c,v 1.12 2003/10/20 21:27:27 hadess Exp $ */
+/* $Id: cpu.c,v 1.14 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,7 @@
 */
 
 #include <glibtop/cpu.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_cpu [GLIBTOP_MAX_CPU] =
 {
@@ -32,7 +32,7 @@ const char *glibtop_names_cpu [GLIBTOP_MAX_CPU] =
 };
 
 const unsigned glibtop_types_cpu [GLIBTOP_MAX_CPU] =
-{ 
+{
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
 	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
