@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id: swap.c,v 1.8 1999/03/30 14:29:36 martin Exp $ */
+/* $Id: swap.c,v 1.11 2004/03/04 15:29:16 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,37 +19,38 @@
    along with LibGTop; see the file COPYING. If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
- */
+*/
 
 #include <glibtop/swap.h>
+#include "libgtop-i18n.h"
 
-const char *glibtop_names_swap[GLIBTOP_MAX_SWAP] =
+const char *glibtop_names_swap [GLIBTOP_MAX_SWAP] =
 {
-    "total", "used", "free", "pagein", "pageout"
+	"total", "used", "free", "pagein", "pageout"
 };
 
-const unsigned glibtop_types_swap[GLIBTOP_MAX_SWAP] =
+const unsigned glibtop_types_swap [GLIBTOP_MAX_SWAP] =
 {
-    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
-    GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
+	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG,
+	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
 };
 
-const char *glibtop_labels_swap[GLIBTOP_MAX_SWAP] =
+const char *glibtop_labels_swap [GLIBTOP_MAX_SWAP] =
 {
-    N_ ("Total Swap Space"),
-    N_ ("Used Swap Space"),
-    N_ ("Free Swap Space"),
-    N_ ("Page In"),
-    N_ ("Page Out"),
+	N_("Total Swap Space"),
+	N_("Used Swap Space"),
+	N_("Free Swap Space"),
+	N_("Page In"),
+	N_("Page Out"),
 };
 
-const char *glibtop_descriptions_swap[GLIBTOP_MAX_SWAP] =
+const char *glibtop_descriptions_swap [GLIBTOP_MAX_SWAP] =
 {
-    N_ ("Total Swap Space"),
-    N_ ("Used Swap Space"),
-    N_ ("Free Swap Space"),
-    N_ ("Total number of swap pages that have been brought in "
-	"since system boot"),
-    N_ ("Total number of swap pages that have been brought out "
-	"since system boot"),
+	N_("Total Swap Space"),
+	N_("Used Swap Space"),
+	N_("Free Swap Space"),
+	N_("Total number of swap pages that have been brought in "
+	   "since system boot"),
+	N_("Total number of swap pages that have been brought out "
+	   "since system boot"),
 };
