@@ -1,4 +1,4 @@
-/* $Id: open_suid.c,v 1.11 2005/08/02 09:47:20 bdejean Exp $ */
+/* $Id: open_suid.c,v 1.10 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,7 @@
 
 #include <glibtop.h>
 #include <glibtop/open.h>
-#include <glibtop/init_hooks.h>
+
 #include <glibtop_suid.h>
 
 #include <unistd.h>
@@ -35,7 +35,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	const glibtop_init_func_t *init_fkt;
+	glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
